<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="kk">
<context>
    <name>KeyboardConfig</name>
    <message>
        <location filename="../keyboardconfig.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="143"/>
        <source>Cursor flash time:</source>
        <translation>Курсор жыпылықтау жиілігі:</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="20"/>
        <source>&lt;b&gt;Keyboard&lt;/b&gt;</source>
        <translation>&lt;b&gt;Пернетақта&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="160"/>
        <source>Beep when there is an error of keyboard input</source>
        <translation>Пернетақтадан енгізу қатесі болғанда дыбыс беру</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="150"/>
        <source> ms</source>
        <translation> мс</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="27"/>
        <source>Character Repeat</source>
        <translation>Таңбаның қайталануы</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="69"/>
        <location filename="../keyboardconfig.ui" line="116"/>
        <source>Long</source>
        <translation>Ұзақ</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="33"/>
        <source>Repeat delay:</source>
        <translation>Қайталау кідірісі:</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="40"/>
        <location filename="../keyboardconfig.ui" line="90"/>
        <source>Short</source>
        <translation>Қысқа</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="83"/>
        <source>Repeat interval:</source>
        <translation>Қайталау аралығы:</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="130"/>
        <source>Type in the following box to test your keyboard settings:</source>
        <translation>Пернетақта баптауларын тексеру үшін келесі өріске теріңіз:</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="76"/>
        <location filename="../keyboardconfig.ui" line="123"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="167"/>
        <source>Turn on NumLock after login</source>
        <translation>Жүйеге кірген соң NumLock іске қосу</translation>
    </message>
</context>
<context>
    <name>KeyboardLayoutConfig</name>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="20"/>
        <source>&lt;b&gt;Keyboard Layout&lt;/b&gt;</source>
        <translation>&lt;b&gt;Пернетақта жаймасы&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="48"/>
        <source>Layout</source>
        <translation>Жайма</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="53"/>
        <source>Variant</source>
        <translation>Нұсқа</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="63"/>
        <source>&amp;Add</source>
        <translation>Қо&amp;су</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="70"/>
        <source>&amp;Remove</source>
        <translation>Өші&amp;ру</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="77"/>
        <source>Up</source>
        <translation>Жоғары</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="84"/>
        <source>Down</source>
        <translation>Төмен</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="108"/>
        <source>Keyboard model:</source>
        <translation>Пернетақта моделі:</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="122"/>
        <source>Keys to change layout:</source>
        <translation>Жайманы ауыстыру пернелері:</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="133"/>
        <source>None</source>
        <translation>Ешнәрсе</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="141"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Note&lt;/span&gt;: If you are using an &lt;span style=&quot; font-weight:600;&quot;&gt;input method&lt;/span&gt;, such as IBus, uim, fcitx, or gcin, the settings here &lt;span style=&quot; font-weight:600;&quot;&gt;might not work&lt;/span&gt; because they are overridden by the input methods.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Ескертпе&lt;/span&gt;: Егер сіз IBus, uim, fcitx немесе gcin сияқты &lt;span style=&quot; font-weight:600;&quot;&gt;енгізу әдісін&lt;/span&gt; қолдансаңыз, мұндағы баптаулар &lt;span style=&quot; font-weight:600;&quot;&gt;жұмыс істемеуі мүмкін&lt;/span&gt;, себебі олар енгізу әдістерімен қайта анықталады.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
</context>
<context>
    <name>MouseConfig</name>
    <message>
        <location filename="../mouseconfig.ui" line="14"/>
        <source>Form</source>
        <translation>Пішін</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="23"/>
        <source>&lt;b&gt;Mouse&lt;/b&gt;</source>
        <translation>&lt;b&gt;Тышқан&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="30"/>
        <source>Double click interval:</source>
        <translation>Қос шерту аралығы:</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="37"/>
        <source> ms</source>
        <translation> мс</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="47"/>
        <source>Wheel scroll lines:</source>
        <translation>Дөңгелекті айналдыру жолдары:</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="64"/>
        <source>Left handed (Swap left and right mouse buttons)</source>
        <translation>Солақайлар үшін (тышқанның сол және оң батырмаларын алмастыру)</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="57"/>
        <source>Single click to activate items</source>
        <translation>Элементтерді белсендіру үшін бір рет шерту</translation>
    </message>
    <message>
        <location filename="../mouseconfig.cpp" line="65"/>
        <source>Use the settings of the Wayland compositor for more options about mouse, touchpad and keyboard.</source>
        <translation>Тышқан, тачпад және пернетақта туралы көбірек опциялар үшін Wayland композиторының баптауларын қолданыңыз.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../lxqt-config-input.cpp" line="41"/>
        <source>LXQt input settings are currently unsupported under Wayland.

Mouse, touchpad and keyboard can be configured in the settings of the compositor.</source>
        <translation>Wayland ортасында LXQt енгізу баптауларына қазіргі уақытта қолдау көрсетілмейді.

Тышқанды, тачпадты және пернетақтаны композитор баптауларында баптауға болады.</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="78"/>
        <source>Keyboard and Mouse Settings</source>
        <translation>Пернетақта және тышқан баптаулары</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="96"/>
        <source>Mouse</source>
        <translation>Тышқан</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="105"/>
        <source>Cursor</source>
        <translation>Курсор</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="110"/>
        <source>To apply the changes also to GTK, check LXQt Appearance Configuration → GTK Style.</source>
        <translation>Өзгерістерді GTK үшін де іске асыру үшін LXQt сыртқы түрін баптау → GTK стилі бөлімін тексеріңіз.</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="114"/>
        <source>Keyboard</source>
        <translation>Пернетақта</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="125"/>
        <source>Keyboard Layout</source>
        <translation>Пернетақта жаймасы</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="138"/>
        <source>Mouse and Touchpad</source>
        <translation>Тышқан және тачпад</translation>
    </message>
</context>
<context>
    <name>SelectKeyboardLayoutDialog</name>
    <message>
        <location filename="../selectkeyboardlayoutdialog.ui" line="14"/>
        <source>Select a keyboard layout</source>
        <translation>Пернетақта жаймасын таңдаңыз</translation>
    </message>
    <message>
        <location filename="../selectkeyboardlayoutdialog.ui" line="20"/>
        <source>Keyboard layout</source>
        <translation>Пернетақта жаймасы</translation>
    </message>
    <message>
        <location filename="../selectkeyboardlayoutdialog.ui" line="27"/>
        <source>Variant</source>
        <translation>Нұсқасы</translation>
    </message>
</context>
<context>
    <name>TouchpadConfig</name>
    <message>
        <location filename="../touchpadconfig.ui" line="14"/>
        <source>TouchpadConfig </source>
        <translation>Тачпад баптаулары </translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="20"/>
        <source>Device:</source>
        <translation>Құрылғы:</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="37"/>
        <source>Acceleration speed:</source>
        <translation>Үдету жылдамдығы:</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="74"/>
        <source>Tap to click</source>
        <translation>Шерту үшін тию</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="60"/>
        <source>Natural Scrolling</source>
        <translation>Табиғи айналдыру</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="67"/>
        <source>Disable while typing</source>
        <translation>Теру кезінде сөндіру</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="83"/>
        <source>Tap and drag</source>
        <translation>Тию және сүйреу</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="106"/>
        <source>Drag lock</source>
        <translation>Сүйреуді бұғаттау</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="133"/>
        <source>Scrolling:</source>
        <translation>Айналдыру:</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="156"/>
        <source>&amp;Disabled</source>
        <translation>Сөн&amp;дірулі</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="163"/>
        <source>&amp;Two-Finger</source>
        <translation>&amp;Екі саусақпен</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="170"/>
        <source>Ed&amp;ge</source>
        <translation>&amp;Жиек</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="177"/>
        <source>B&amp;utton</source>
        <translation>&amp;Батырма</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="30"/>
        <source>DeviceInfoLabel</source>
        <translation>Құрылғы ақпаратының белгісі</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.cpp" line="102"/>
        <source>LXQt only supports &quot;libinput&quot; as xinput driver.
(current value: %1)

If this is intended, please configure xinput manually.
Otherwise you can get rid of this message by changing xinput driver to &quot;libinput&quot;.
</source>
        <translation>LXQt xinput драйвері ретінде тек &quot;libinput&quot; драйверін қолдайды.
(ағымдағы мәні: %1)

Егер бұл мақсатты түрде жасалса, xinput драйверін қолмен баптаңыз.
Әйтпесе xinput драйверін &quot;libinput&quot; етіп өзгерту арқылы бұл хабарламадан құтыла аласыз.
</translation>
    </message>
</context>
</TS>
